---
title: '[공지] KG이니시스 “삼성monimo” 앱 스킴 등록 안내'
category: 공지사항
tags:
  - 공지사항
datetime: 2024-04-09T06:47:10.391Z
---

안녕하세요, 포트원 고객지원팀입니다.

KG이니시스 앱 스킴 추가 등록 관련하여 하기 내용 참고 부탁드립니다.

감사합니다.

![](/uploads/포트원소식/앰스킴등록.png)
